function sync = entropy_measure(ph,sampf)
% this function computes phase synchronization using shannon entropy method
% over an analysis window of fixed length

% inputs to this function - phase, sampling frequency
% output from this function - synchronization measure
% processing performed - configures the bins for a given analysis window
% length, computes the probability distibution of values for every interval
% of analysis, and evaluates the entropy based measure

% set window length over which the measure has to be computed
win_sec = 2; % in sec

%set skip length in number of samples
skip_len=1;

% compute the window length
win_len= win_sec * sampf; % in no of samples

% defining optimal number of bins
%total number of bins in a given window
tot_bins = ceil(exp(0.626 + 0.4 * log(win_len-1)));

%compute the vector of bins
bins = single(0 : pi/tot_bins : pi);

%get the total length of data
len=length(ph);

% compute entropy for each analysis window
for t=1:skip_len:len-win_len+1

    %obtain the histrogram for the current interval
    hist_val = histc(ph(t:t+win_len-1), bins);

    %compute entropy for the current interval
    ent = compute_entropy(hist_val,win_len);

    %store the entropy value for the currnet interval
    shanon_entropy(t) = ent;
end

%theoretical maximum that entropy can reach in this configuration
max_shanon_entropy = log(tot_bins);

%compute the synchronization over a 0 to 1 measure
sync = (1 - (shanon_entropy / max_shanon_entropy) );

end