% Implementation of Hilbert transform based phase synchronization measure

% Please quote Prasad et al., "Enhanced Phase and Amplitude Synchronization
% towards Focal Seizure Offset", Journal of Clinical EEG and Neuroscience,
% volume 44, issue 1, 2013, page 16-27    % DOI: 10.1177/1550059412456093

%setting up the program
clear all;
close all;
clear global;
clc;

%user supplied parameters are to be set here

%set the file name for channel 1
file_name1 = 'patient3_seizure5_ch1.asc';

%set the file name for channel 2
file_name2 = 'patient3_seizure5_ch2.asc';

% set sampling frequency in Hz
sampf = 256; % in Hz

% set onset time of seizure as noted by epileptologist
epi_onset = 51836  ; % in sample number

% set offset time of seizure as noted by epileptologist
epi_offset = 58234 ; % in sample number

% set whether to plot the result
plot_result = 1;

% set output filename
outputfile1 = 'result1.png';

%%load the data from file

%load the file for channel 1
ch1 = load(file_name1);
disp(['loaded file 1: ' file_name1]);
%load the file for channel 2
ch2 = load(file_name2);
disp(['loaded file 2: ' file_name2])
disp ' '

disp(['sampling frequency: ' num2str(sampf) ' Hz'])
% compute seizure onset time in sec
sz_onset = epi_onset/sampf;
disp(['seizure onset: ' num2str(sz_onset) ' sec'])
% compute seizure onset time in sec
sz_offset = epi_offset/sampf;
disp(['seizure offset: ' num2str(sz_offset) ' sec'])
disp ' '

%call function to compute phase synchronization
disp 'begin processing two channel data..'
hilbert_phase_synch(ch1,ch2,sampf,sz_onset,sz_offset,outputfile1);
% disp 'finished processing data..'

%end of program