function hilbert_phase_synch(ch1,ch2,sampf,sz_onset,sz_offset,outputfile)
% this function computes the hilbert transform based phase synchronization
% measure over a specific frequency band of interest between two discrete
% time signals at a particular sampling frequency

%input required by this module - input channels and sampling frequency
%   seizure onset and offset times, outputfile name
%output supplied by this module - none
%action performed - filter the input data for - frequency band of interest,
% suppress line noise

disp 'computing the filter response'
%get filter coefficients depending on the band
% select lower gamma 30-40 Hz
Hlg = lower_gamma_band_bandpass_filter(sampf);

% select alpha band 8-12 Hz
% Ha = alpha_band_bandpass_filter(sampf);

% select beta band 13-30 Hz
% Hb = beta_band_bandpass_filter(sampf);

% select gamma band 30-80 Hz
% Hg = gamma_band_bandpass_filter(sampf);

% select delta band 1-4 Hz
% Hd = delta_band_bandpass_filter(sampf);

% select theta band 4-8 Hz
% Ht = theta_band_bandpass_filter(sampf);

%perform filtering using filtfilt function for zero phase distortion
%note:resulting transfer function is the squared magnitude of the original
disp 'filtering data..'
%process channel 1 data
data = double(ch1);
ch1_filt = filtfilt(Hlg,1,data);
%process channel 2 data
data = double(ch2);
ch2_filt = filtfilt(Hlg,1,data);
disp ' '

%call function to compute hilbert phase
%process channel 1 data
disp 'computing hilbert phase'
ch1_ph = hilbert_phase(ch1_filt);
%process channel 2 data
ch2_ph = hilbert_phase(ch2_filt);

%compute phase difference between the two channels and express the result
% uniquely in the range of 0 to 2pi rad
disp 'computing phase difference'
ph_diff = mod(ch1_ph-ch2_ph,2*pi);

%call function to compute synchronization level

% shannon entropy based phase synchronization measure
disp 'evaluating phase sync..'
sync = entropy_measure(ph_diff,sampf);
disp ' '

%set statisitical significance level
sig_level = 0.1;

%plot the results
disp 'ploting results..'
%draw phase sync
plot((1:length(sync))/sampf, sync);
hold on;
%draw vertical markers to mark seizure onset and offset
plot(sz_onset,0:.001:.5,'k');
plot(sz_offset,0:.001:.5,'k');
%draw statisitcal significance level
line([1 length(sync)]/sampf,[sig_level sig_level],'Color','r');
%graph annotations
grid on;
title('Hilbert transform based Phase Synchronization');
xlabel('Time (in sec)');
ylabel('Phase Synchronization');
%save the plot
saveas(gcf,outputfile,'png')

end
