function schindler_algo(ch1,ch2,ch3,sampf,sz_onset,sz_offset,outputfile)
% this function implements a method proposed by schindler which computes 
% the eigenvalues of correlation matrix among 'n' distinct channels as a 
% measure over a specific frequency band of interest

%input required by this module - input channels and sampling frequency
%   seizure onset and offset times, outputfile name
%output supplied by this module - none
%action performed - filter the input data for - frequency band of interest, 
% suppress line noise

disp 'computing the filter response'
%get filter coefficients depending on the band
% select lower gamma 30-40 Hz
Hlg = lower_gamma_band_bandpass_filter(sampf);

% select alpha band 8-12 Hz
% Ha = alpha_band_bandpass_filter(sampf);

% select beta band 13-30 Hz
% Hb = beta_band_bandpass_filter(sampf);

% select gamma band 30-80 Hz
% Hg = gamma_band_bandpass_filter(sampf);

% select delta band 1-4 Hz
% Hd = delta_band_bandpass_filter(sampf);

% select theta band 4-8 Hz
% Ht = theta_band_bandpass_filter(sampf);

%perform filtering using filtfilt function for zero phase distortion
%note:resulting transfer function is the squared magnitude of the original
disp 'filtering data..'
%process channel 1 data
data = double(ch1);
ch1_filt = filtfilt(Hlg,1,data);
%process channel 2 data
data = double(ch2);
ch2_filt = filtfilt(Hlg,1,data);
%process channel 3 data
data = double(ch3);
ch3_filt = filtfilt(Hlg,1,data);
disp ' '

%length of data to be processed
ch_len = length(data);
% set window length over which the measure has to be computed 
win_len = 2*sampf;
%set increment value in samples
incr = 1;

%setting intial value
n=1;

% processing of all three channel data
disp 'processing data..'
for w = 1:incr:ch_len-win_len+1
    dat(:,1) = ch1_filt(w:w+win_len-1);
    dat(:,2) = ch2_filt(w:w+win_len-1);
    dat(:,3) = ch3_filt(w:w+win_len-1);

    corr_dat = corrcoef(dat);
    corr_dat(isnan(corr_dat)) = 0;
    eig_val(:,n) = sort(eig(corr_dat),'descend');
    
    n = n + 1;
end

%set smoothing time  in seconds
smooth_len = 1 * sampf + 1;
% perform smoothing of eigen values to help easy visualization
disp 'performing smoothening of results..'
for ii = 1: 3
    eig_val(ii,:) = smooth(eig_val(ii,:), smooth_len);
end

len = size(eig_val,2);

%plot the results
disp 'ploting results..'
%draw schindler results
plot((1:len)/sampf, eig_val(1,:),'b');
hold on;
plot((1:len)/sampf, eig_val(2,:),'g');
plot((1:len)/sampf, eig_val(3,:),'r');
%draw vertical markers to mark seizure onset and offset
plot(sz_onset,0:.001:3,'k');
plot(sz_offset,0:.001:3,'k');
%graph annotations
grid on;
title('Progression of Eigenvalues of correlation matrix');
xlabel('Time (in sec)');
ylabel('Eigenvalues');
%save the plot
saveas(gcf,outputfile,'png')

end
